import React, { useState } from 'react'
import IUserDto from '../../interfaces/IUserCreateDto'
import styles from './Login.module.css'
import {Link} from 'react-router-dom'
import { shallowEqual, useDispatch, useSelector } from 'react-redux'
import { AppDispatch, AppState } from '../../store/store'
import {login} from '../../store/users/users.slice'


const Login: React.FunctionComponent = (): React.ReactElement => {
    const {messageUser} = useSelector((state: AppState) => state.users, shallowEqual)
    const dispatch: AppDispatch = useDispatch()
    const [values, setValues] = useState<IUserDto>({
        username: '',
        password: ''
    })
    const inputHandler = (e: React.ChangeEvent<HTMLInputElement>): void => {
        setValues(prevState => {
            return {...prevState, [e.target.name]: e.target.value}
        })
    }
    const loginHandler = async (e: React.FormEvent) => {
        e.preventDefault()
        dispatch(login(values))
    }
    return (
        <>
                <div>
                    <form onSubmit={loginHandler} className={styles.Login}>
                        <span>{messageUser}</span>
                        <input onChange={inputHandler} value={values.username} placeholder='Username' className={styles.Login__input} type="text" name={'username'} required />
                        <input onChange={inputHandler} value={values.password} placeholder='Password' className={styles.Login__input} type="password" name={'password'} required />
                        <button className={styles.Login__button}>Sign in</button>
                        <Link to={'/register'} className={styles.Login__button}>Sign up now</Link>
                    </form>
                </div>
        </>
        
    )
}

export default Login